pub struct Spline {
pub is_closed: bool,
pub times: Vec<Time>,
pub values: Vec<SplineKeyframeValues>,
}Expand description
Animated cubic spline.
Fields
is_closed: boolTrue if the spline is closed.
times: Vec<Time>Collection of times.
values: Vec<SplineKeyframeValues>Collection of splines for each time. The splines at each point must have a start, but may also have an end defined. When the end is not defined, then the next keyframe’s start is used.
Implementations